/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 106 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQFontMetricsF.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQFontMetricsF.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQFontMetricsF.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQFontMetricsF.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQFontMetricsF.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qtextoption.sip"
#include <qtextoption.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQFontMetricsF.cpp"
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQFontMetricsF.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQFontMetricsF.cpp"
#line 114 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQFontMetricsF.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qchar.sip"
#include <qchar.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQFontMetricsF.cpp"


PyDoc_STRVAR(doc_QFontMetricsF_ascent, "ascent(self) -> float");

extern "C" {static PyObject *meth_QFontMetricsF_ascent(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_ascent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontMetricsF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->ascent();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_ascent, doc_QFontMetricsF_ascent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_descent, "descent(self) -> float");

extern "C" {static PyObject *meth_QFontMetricsF_descent(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_descent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontMetricsF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->descent();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_descent, doc_QFontMetricsF_descent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_height, "height(self) -> float");

extern "C" {static PyObject *meth_QFontMetricsF_height(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_height(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontMetricsF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->height();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_height, doc_QFontMetricsF_height);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_leading, "leading(self) -> float");

extern "C" {static PyObject *meth_QFontMetricsF_leading(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_leading(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontMetricsF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->leading();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_leading, doc_QFontMetricsF_leading);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_lineSpacing, "lineSpacing(self) -> float");

extern "C" {static PyObject *meth_QFontMetricsF_lineSpacing(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_lineSpacing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontMetricsF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->lineSpacing();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_lineSpacing, doc_QFontMetricsF_lineSpacing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_minLeftBearing, "minLeftBearing(self) -> float");

extern "C" {static PyObject *meth_QFontMetricsF_minLeftBearing(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_minLeftBearing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontMetricsF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->minLeftBearing();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_minLeftBearing, doc_QFontMetricsF_minLeftBearing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_minRightBearing, "minRightBearing(self) -> float");

extern "C" {static PyObject *meth_QFontMetricsF_minRightBearing(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_minRightBearing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontMetricsF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->minRightBearing();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_minRightBearing, doc_QFontMetricsF_minRightBearing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_maxWidth, "maxWidth(self) -> float");

extern "C" {static PyObject *meth_QFontMetricsF_maxWidth(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_maxWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontMetricsF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->maxWidth();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_maxWidth, doc_QFontMetricsF_maxWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_xHeight, "xHeight(self) -> float");

extern "C" {static PyObject *meth_QFontMetricsF_xHeight(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_xHeight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontMetricsF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->xHeight();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_xHeight, doc_QFontMetricsF_xHeight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_inFont, "inFont(self, a0: str) -> bool");

extern "C" {static PyObject *meth_QFontMetricsF_inFont(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_inFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QChar* a0;
        int a0State = 0;
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QFontMetricsF, &sipCpp, sipType_QChar, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->inFont(*a0);
            sipReleaseType(a0, sipType_QChar, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_inFont, doc_QFontMetricsF_inFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_leftBearing, "leftBearing(self, a0: str) -> float");

extern "C" {static PyObject *meth_QFontMetricsF_leftBearing(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_leftBearing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QChar* a0;
        int a0State = 0;
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QFontMetricsF, &sipCpp, sipType_QChar, &a0, &a0State))
        {
            ::qreal sipRes;

            sipRes = sipCpp->leftBearing(*a0);
            sipReleaseType(a0, sipType_QChar, a0State);

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_leftBearing, doc_QFontMetricsF_leftBearing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_rightBearing, "rightBearing(self, a0: str) -> float");

extern "C" {static PyObject *meth_QFontMetricsF_rightBearing(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_rightBearing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QChar* a0;
        int a0State = 0;
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QFontMetricsF, &sipCpp, sipType_QChar, &a0, &a0State))
        {
            ::qreal sipRes;

            sipRes = sipCpp->rightBearing(*a0);
            sipReleaseType(a0, sipType_QChar, a0State);

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_rightBearing, doc_QFontMetricsF_rightBearing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_boundingRect, "boundingRect(self, text: str|None, textOption: QTextOption) -> QRectF\n"
"boundingRect(self, string: str|None) -> QRectF\n"
"boundingRect(self, rect: QRectF, flags: int, text: str|None, tabStops: int = 0, tabArray: list[int]|None = None) -> QRectF");

extern "C" {static PyObject *meth_QFontMetricsF_boundingRect(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_boundingRect(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QTextOption* a1;
        const ::QFontMetricsF *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J9", &sipSelf, sipType_QFontMetricsF, &sipCpp, sipType_QString, &a0, &a0State, sipType_QTextOption, &a1))
        {
            ::QRectF*sipRes;

            sipRes = new ::QRectF(sipCpp->boundingRect(*a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QRectF, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QFontMetricsF *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QFontMetricsF, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QRectF*sipRes;

            sipRes = new ::QRectF(sipCpp->boundingRect(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QRectF, SIP_NULLPTR);
        }
    }

    {
        const ::QRectF* a0;
        int a1;
        const ::QString* a2;
        int a2State = 0;
        int a3 = 0;
        PyObject * a4 = 0;
        const ::QFontMetricsF *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_tabStops,
            sipName_tabArray,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9iJ1|iN", &sipSelf, sipType_QFontMetricsF, &sipCpp, sipType_QRectF, &a0, &a1, sipType_QString, &a2, &a2State, &a3, &PyList_Type, &a4))
        {
            ::QRectF*sipRes = 0;

#line 134 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontmetrics.sip"
        int *tabarray = qtgui_tabarray(a4);
        
        sipRes = new QRectF(sipCpp->boundingRect(*a0, a1, *a2, a3, tabarray));
        
        if (!tabarray)
            delete[] tabarray;
#line 453 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQFontMetricsF.cpp"
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);

            return sipConvertFromNewType(sipRes, sipType_QRectF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_boundingRect, doc_QFontMetricsF_boundingRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_boundingRectChar, "boundingRectChar(self, a0: str) -> QRectF");

extern "C" {static PyObject *meth_QFontMetricsF_boundingRectChar(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_boundingRectChar(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QChar* a0;
        int a0State = 0;
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QFontMetricsF, &sipCpp, sipType_QChar, &a0, &a0State))
        {
            ::QRectF*sipRes;

            sipRes = new ::QRectF(sipCpp->boundingRect(*a0));
            sipReleaseType(a0, sipType_QChar, a0State);

            return sipConvertFromNewType(sipRes, sipType_QRectF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_boundingRectChar, doc_QFontMetricsF_boundingRectChar);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_size, "size(self, flags: int, text: str|None, tabStops: int = 0, tabArray: list[int]|None = None) -> QSizeF");

extern "C" {static PyObject *meth_QFontMetricsF_size(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_size(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QString* a1;
        int a1State = 0;
        int a2 = 0;
        PyObject * a3 = 0;
        const ::QFontMetricsF *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_tabStops,
            sipName_tabArray,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BiJ1|iN", &sipSelf, sipType_QFontMetricsF, &sipCpp, &a0, sipType_QString, &a1, &a1State, &a2, &PyList_Type, &a3))
        {
            ::QSizeF*sipRes = 0;

#line 144 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontmetrics.sip"
        int *tabarray = qtgui_tabarray(a3);
        
        sipRes = new QSizeF(sipCpp->size(a0, *a1, a2, tabarray));
        
        if (!tabarray)
            delete[] tabarray;
#line 528 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQFontMetricsF.cpp"
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QSizeF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_size, doc_QFontMetricsF_size);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_underlinePos, "underlinePos(self) -> float");

extern "C" {static PyObject *meth_QFontMetricsF_underlinePos(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_underlinePos(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontMetricsF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->underlinePos();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_underlinePos, doc_QFontMetricsF_underlinePos);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_overlinePos, "overlinePos(self) -> float");

extern "C" {static PyObject *meth_QFontMetricsF_overlinePos(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_overlinePos(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontMetricsF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->overlinePos();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_overlinePos, doc_QFontMetricsF_overlinePos);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_strikeOutPos, "strikeOutPos(self) -> float");

extern "C" {static PyObject *meth_QFontMetricsF_strikeOutPos(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_strikeOutPos(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontMetricsF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->strikeOutPos();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_strikeOutPos, doc_QFontMetricsF_strikeOutPos);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_lineWidth, "lineWidth(self) -> float");

extern "C" {static PyObject *meth_QFontMetricsF_lineWidth(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_lineWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontMetricsF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->lineWidth();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_lineWidth, doc_QFontMetricsF_lineWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_averageCharWidth, "averageCharWidth(self) -> float");

extern "C" {static PyObject *meth_QFontMetricsF_averageCharWidth(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_averageCharWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontMetricsF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->averageCharWidth();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_averageCharWidth, doc_QFontMetricsF_averageCharWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_elidedText, "elidedText(self, text: str|None, mode: Qt.TextElideMode, width: float, flags: int = 0) -> str");

extern "C" {static PyObject *meth_QFontMetricsF_elidedText(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_elidedText(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::Qt::TextElideMode a1;
        ::qreal a2;
        int a3 = 0;
        const ::QFontMetricsF *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_flags,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1Ed|i", &sipSelf, sipType_QFontMetricsF, &sipCpp, sipType_QString, &a0, &a0State, sipType_Qt_TextElideMode, &a1, &a2, &a3))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->elidedText(*a0, a1, a2, a3));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_elidedText, doc_QFontMetricsF_elidedText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_tightBoundingRect, "tightBoundingRect(self, text: str|None, textOption: QTextOption) -> QRectF\n"
"tightBoundingRect(self, text: str|None) -> QRectF");

extern "C" {static PyObject *meth_QFontMetricsF_tightBoundingRect(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_tightBoundingRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QTextOption* a1;
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J9", &sipSelf, sipType_QFontMetricsF, &sipCpp, sipType_QString, &a0, &a0State, sipType_QTextOption, &a1))
        {
            ::QRectF*sipRes;

            sipRes = new ::QRectF(sipCpp->tightBoundingRect(*a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QRectF, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QFontMetricsF, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QRectF*sipRes;

            sipRes = new ::QRectF(sipCpp->tightBoundingRect(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QRectF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_tightBoundingRect, doc_QFontMetricsF_tightBoundingRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_inFontUcs4, "inFontUcs4(self, character: int) -> bool");

extern "C" {static PyObject *meth_QFontMetricsF_inFontUcs4(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_inFontUcs4(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::uint a0;
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QFontMetricsF, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->inFontUcs4(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_inFontUcs4, doc_QFontMetricsF_inFontUcs4);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_swap, "swap(self, other: QFontMetricsF)");

extern "C" {static PyObject *meth_QFontMetricsF_swap(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QFontMetricsF* a0;
        ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QFontMetricsF, &sipCpp, sipType_QFontMetricsF, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_swap, doc_QFontMetricsF_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_capHeight, "capHeight(self) -> float");

extern "C" {static PyObject *meth_QFontMetricsF_capHeight(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_capHeight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontMetricsF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->capHeight();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_capHeight, doc_QFontMetricsF_capHeight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_horizontalAdvance, "horizontalAdvance(self, string: str|None, textOption: QTextOption) -> float\n"
"horizontalAdvance(self, string: str|None, length: int = -1) -> float");

extern "C" {static PyObject *meth_QFontMetricsF_horizontalAdvance(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_horizontalAdvance(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QTextOption* a1;
        const ::QFontMetricsF *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J9", &sipSelf, sipType_QFontMetricsF, &sipCpp, sipType_QString, &a0, &a0State, sipType_QTextOption, &a1))
        {
            ::qreal sipRes;

            sipRes = sipCpp->horizontalAdvance(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyFloat_FromDouble(sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        int a1 = -1;
        const ::QFontMetricsF *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_length,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|i", &sipSelf, sipType_QFontMetricsF, &sipCpp, sipType_QString, &a0, &a0State, &a1))
        {
            ::qreal sipRes;

            sipRes = sipCpp->horizontalAdvance(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_horizontalAdvance, doc_QFontMetricsF_horizontalAdvance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QFontMetricsF_fontDpi, "fontDpi(self) -> float");

extern "C" {static PyObject *meth_QFontMetricsF_fontDpi(PyObject *, PyObject *);}
static PyObject *meth_QFontMetricsF_fontDpi(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontMetricsF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QFontMetricsF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->fontDpi();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QFontMetricsF, sipName_fontDpi, doc_QFontMetricsF_fontDpi);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QFontMetricsF___ne__(PyObject *, PyObject *);}
static PyObject *slot_QFontMetricsF___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QFontMetricsF *sipCpp = reinterpret_cast< ::QFontMetricsF *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QFontMetricsF));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontMetricsF* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QFontMetricsF, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QFontMetricsF::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtGui, ne_slot, sipType_QFontMetricsF, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QFontMetricsF___eq__(PyObject *, PyObject *);}
static PyObject *slot_QFontMetricsF___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QFontMetricsF *sipCpp = reinterpret_cast< ::QFontMetricsF *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QFontMetricsF));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFontMetricsF* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QFontMetricsF, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QFontMetricsF::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtGui, eq_slot, sipType_QFontMetricsF, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QFontMetricsF(void *, int);}
static void release_QFontMetricsF(void *sipCppV, int)
{
    delete reinterpret_cast< ::QFontMetricsF *>(sipCppV);
}


extern "C" {static void assign_QFontMetricsF(void *, Py_ssize_t, void *);}
static void assign_QFontMetricsF(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QFontMetricsF *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QFontMetricsF *>(sipSrc);
}


extern "C" {static void *copy_QFontMetricsF(const void *, Py_ssize_t);}
static void *copy_QFontMetricsF(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QFontMetricsF(reinterpret_cast<const ::QFontMetricsF *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QFontMetricsF(sipSimpleWrapper *);}
static void dealloc_QFontMetricsF(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QFontMetricsF(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QFontMetricsF(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QFontMetricsF(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QFontMetricsF *sipCpp = SIP_NULLPTR;

    {
        const ::QFont* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QFont, &a0))
        {
            sipCpp = new ::QFontMetricsF(*a0);

            return sipCpp;
        }
    }

    {
        const ::QFont* a0;
        const ::QPaintDevice* a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9J8", sipType_QFont, &a0, sipType_QPaintDevice, &a1))
        {
            sipCpp = new ::QFontMetricsF(*a0, a1);

            return sipCpp;
        }
    }

    {
        const ::QFontMetrics* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QFontMetrics, &a0))
        {
            sipCpp = new ::QFontMetricsF(*a0);

            return sipCpp;
        }
    }

    {
        const ::QFontMetricsF* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QFontMetricsF, &a0))
        {
            sipCpp = new ::QFontMetricsF(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QFontMetricsF[] = {
    {(void *)slot_QFontMetricsF___ne__, ne_slot},
    {(void *)slot_QFontMetricsF___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QFontMetricsF[] = {
    {sipName_ascent, meth_QFontMetricsF_ascent, METH_VARARGS, doc_QFontMetricsF_ascent},
    {sipName_averageCharWidth, meth_QFontMetricsF_averageCharWidth, METH_VARARGS, doc_QFontMetricsF_averageCharWidth},
    {sipName_boundingRect, SIP_MLMETH_CAST(meth_QFontMetricsF_boundingRect), METH_VARARGS|METH_KEYWORDS, doc_QFontMetricsF_boundingRect},
    {sipName_boundingRectChar, meth_QFontMetricsF_boundingRectChar, METH_VARARGS, doc_QFontMetricsF_boundingRectChar},
    {sipName_capHeight, meth_QFontMetricsF_capHeight, METH_VARARGS, doc_QFontMetricsF_capHeight},
    {sipName_descent, meth_QFontMetricsF_descent, METH_VARARGS, doc_QFontMetricsF_descent},
    {sipName_elidedText, SIP_MLMETH_CAST(meth_QFontMetricsF_elidedText), METH_VARARGS|METH_KEYWORDS, doc_QFontMetricsF_elidedText},
    {sipName_fontDpi, meth_QFontMetricsF_fontDpi, METH_VARARGS, doc_QFontMetricsF_fontDpi},
    {sipName_height, meth_QFontMetricsF_height, METH_VARARGS, doc_QFontMetricsF_height},
    {sipName_horizontalAdvance, SIP_MLMETH_CAST(meth_QFontMetricsF_horizontalAdvance), METH_VARARGS|METH_KEYWORDS, doc_QFontMetricsF_horizontalAdvance},
    {sipName_inFont, meth_QFontMetricsF_inFont, METH_VARARGS, doc_QFontMetricsF_inFont},
    {sipName_inFontUcs4, meth_QFontMetricsF_inFontUcs4, METH_VARARGS, doc_QFontMetricsF_inFontUcs4},
    {sipName_leading, meth_QFontMetricsF_leading, METH_VARARGS, doc_QFontMetricsF_leading},
    {sipName_leftBearing, meth_QFontMetricsF_leftBearing, METH_VARARGS, doc_QFontMetricsF_leftBearing},
    {sipName_lineSpacing, meth_QFontMetricsF_lineSpacing, METH_VARARGS, doc_QFontMetricsF_lineSpacing},
    {sipName_lineWidth, meth_QFontMetricsF_lineWidth, METH_VARARGS, doc_QFontMetricsF_lineWidth},
    {sipName_maxWidth, meth_QFontMetricsF_maxWidth, METH_VARARGS, doc_QFontMetricsF_maxWidth},
    {sipName_minLeftBearing, meth_QFontMetricsF_minLeftBearing, METH_VARARGS, doc_QFontMetricsF_minLeftBearing},
    {sipName_minRightBearing, meth_QFontMetricsF_minRightBearing, METH_VARARGS, doc_QFontMetricsF_minRightBearing},
    {sipName_overlinePos, meth_QFontMetricsF_overlinePos, METH_VARARGS, doc_QFontMetricsF_overlinePos},
    {sipName_rightBearing, meth_QFontMetricsF_rightBearing, METH_VARARGS, doc_QFontMetricsF_rightBearing},
    {sipName_size, SIP_MLMETH_CAST(meth_QFontMetricsF_size), METH_VARARGS|METH_KEYWORDS, doc_QFontMetricsF_size},
    {sipName_strikeOutPos, meth_QFontMetricsF_strikeOutPos, METH_VARARGS, doc_QFontMetricsF_strikeOutPos},
    {sipName_swap, meth_QFontMetricsF_swap, METH_VARARGS, doc_QFontMetricsF_swap},
    {sipName_tightBoundingRect, meth_QFontMetricsF_tightBoundingRect, METH_VARARGS, doc_QFontMetricsF_tightBoundingRect},
    {sipName_underlinePos, meth_QFontMetricsF_underlinePos, METH_VARARGS, doc_QFontMetricsF_underlinePos},
    {sipName_xHeight, meth_QFontMetricsF_xHeight, METH_VARARGS, doc_QFontMetricsF_xHeight}
};

PyDoc_STRVAR(doc_QFontMetricsF, "\1QFontMetricsF(a0: QFont)\n"
"QFontMetricsF(font: QFont, pd: QPaintDevice|None)\n"
"QFontMetricsF(a0: QFontMetrics)\n"
"QFontMetricsF(a0: QFontMetricsF)");


sipClassTypeDef sipTypeDef_QtGui_QFontMetricsF = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QFontMetricsF,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QFontMetricsF,
        {0, 0, 1},
        27, methods_QFontMetricsF,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QFontMetricsF,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QFontMetricsF,
    init_type_QFontMetricsF,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QFontMetricsF,
    assign_QFontMetricsF,
    SIP_NULLPTR,
    copy_QFontMetricsF,
    release_QFontMetricsF,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QFontMetricsF),
};
